========
baumdiff
========

`baumdiff` is a pure-Python library for comparison and three-way merging of ordered trees.

Installation
------------

Simply install the package via pip::

    pip install baumdiff
